@@ -63,8 +63,8 @@ class MemcachedCacheBackend(CacheBackendProtocol):
             Cached value if existing else `None`.
         """
 
-        value = await self._memcached_client.get(key=key.encode("utf-8"))  # type: ignore
-        return self._config.deserialize(value)
+        value = await self._memcached_client.get(key=key.encode("utf-8"))
+        return self._config.deserialize(value)  # type: ignore[arg-type]
 
     async def set(self, key: str, value: Any, expiration: int) -> None:  # pylint: disable=invalid-overridden-method
         """Set sa value in cache for a given key for a duration determined by expiration.
